@@ -47,6 +47,10 @@ class Application(Gtk.Application):
         GLib.set_application_name(APP_NAME)
         GLib.set_prgname(APP_ID)
 
+        # resource icons in icon theme path
+        icon_theme = Gtk.IconTheme.get_default()
+        icon_theme.add_resource_path("/net/kirgroup/confy/icons")
+
         # custom css
         css_provider = Gtk.CssProvider()
         css_provider.load_from_resource("/net/kirgroup/confy/confy.css")
@@ -65,10 +69,12 @@ class Application(Gtk.Application):
         Handy.init()
         Notify.init(APP_NAME)
         local.init(APP_ID)
+
         quit_action = Gio.SimpleAction.new("quit", None)
         quit_action.connect("activate", lambda *args: self.quit() )
         self.add_action(quit_action)
         self.set_accels_for_action("app.quit", ["<Primary>q",])
+
         shortcut_action = Gio.SimpleAction.new("shortcuts")
         shortcut_action.connect("activate", self.show_shortcuts)
         self.add_action(shortcut_action)
