@@ -95,11 +95,13 @@ class BaseListPage(BasePage):
         title = title or self.title
         subtitle = subtitle or self.subtitle
 
+        self.get_style_context().add_class("list-page")
+
         box = Gtk.VBox()
         box.get_style_context().add_class("main-box")
 
         if title != "" or subtitle != "":
-            titlebox = Gtk.VBox(margin_left=8, margin_right=8)
+            titlebox = Gtk.VBox()
             if title != "":
                 label = Gtk.Label(halign=Gtk.Align.START)
                 label.set_markup("<b>{}</b>".format(title.replace("&", "&amp;")))
@@ -136,11 +138,21 @@ class BaseListPage(BasePage):
         for w in self.listbox.get_children():
             w.destroy()
 
-        lastgroup = None
-        for obj in self.data:
-            mn = self.build_row(obj)
+        count = len(self.data)
 
+        for n, obj in enumerate(self.data):
+            mn = self.build_row(obj)
             self.listbox.add(mn)
+
+            # add "first" and "last" class to row
+            # :first-child and :last-child doesn't work reliably, so we fake this
+            # we need to know which row is first and wich is last to handle round
+            # corners rendering the event progress indicator.
+            # see widgets.EventActionRow._on_draw()
+            if n == 0:
+                mn.get_style_context().add_class("first")
+            if n == count-1:
+                mn.get_style_context().add_class("last")
         self.listbox.show_all()
 
     def get_objects(self):
@@ -195,6 +207,7 @@ class ConferencePage(BasePage):
         }
 
         box = Gtk.VBox(valign=Gtk.Align.CENTER)
+        box.get_style_context().add_class("main-box")
 
         self.logoimage = MaxSizedImage(max_width=200, max_height=200)
         f = conf.get_logo_file(cbk=self._set_logo)
@@ -440,6 +453,8 @@ class EventDetailPage(BasePage):
 
         icon_name = "starred-symbolic" if obj.starred else "non-starred-symbolic"
         self.toggle_btn = Gtk.Button.new_from_icon_name(icon_name, Gtk.IconSize.BUTTON)
+        self.toggle_btn.set_halign(Gtk.Align.END)
+        self.toggle_btn.set_valign(Gtk.Align.CENTER)
         self.toggle_btn.connect("clicked", self.toggle_starred)
         starbox.pack_end(self.toggle_btn, False, False, 16)
 
@@ -450,7 +465,7 @@ class EventDetailPage(BasePage):
             cbox = Gtk.VBox()
             label = Gtk.Label(**LBL_PROPS)
             label.set_markup(_("<b>Conflicts with</b>"))
-            cbox.pack_start(label, False, False, 0)
+            cbox.pack_start(label, False, False, 2)
             frame = Gtk.Frame()
             listbox = Gtk.ListBox()
             listbox.connect('row-activated', self.on_conflict_activated)
@@ -480,7 +495,7 @@ class EventDetailPage(BasePage):
             linkbox = Gtk.VBox()
             label = Gtk.Label(**LBL_PROPS)
             label.set_markup(_("<b>Links</b>"))
-            linkbox.pack_start(label, False, False, 0)
+            linkbox.pack_start(label, False, False, 2)
 
             frame = Gtk.Frame()
             listbox = Gtk.ListBox()
@@ -520,7 +535,8 @@ class EventDetailPage(BasePage):
 
         x = w * prc
 
-        cr.set_source_rgb(0, 0, 0)
+        cr.set_source_rgba(0,0,0,0.2)
+        cr.set_line_width(8)
         cr.move_to(0, 1)
         cr.line_to(x, 1)
         cr.stroke()
@@ -544,8 +560,8 @@ class StarredPage(BaseListPage):
             _("Starred Talks"),
             _("You don't have any starred talk yet.") + "\n" + \
             _("Click on the star button to add a talk to this list " + \
-                "and to be reminded when they are about to start."),
-            "starred")
+                "and to be reminded when they are about to start.")
+        )
         self.empty_placeholder.show_all()
         self.nomatch_placeholder = PlaceholderWidget(
             text = _("No matches found"),
